/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*             UNIDAD DE EVALUACIN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIN GENERAL DE MEDICIN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                         **** CIENCIAS NATURALES****
/*
/*                     Ciclo escolar evaluado: 2013 - 2014
/*_____________________________________________________________________________
/*
/*
/*        SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CIENCIAS
/*                                  EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale03_2014_Alum_CN.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2014_Alum_CN.txt
/*         as como el archivo Excale03_2014_Alum_CN.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale03_2014_Alum_CN.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2014_Alum_CN.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Direccin de Tratamiento de Datos
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/*FECHA DE LIBERACIN: 01 DE SEPTIEMBRE 2015
/*
/*  ****************************************************************************/




LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale03_2014_Alum_CN.TXT";

PROC FORMAT;
     VALUE id_entF     1         =  "Aguascalientes"
                       2         =  "Baja California"
                       3         =  "Baja California Sur"
                       4         =  "Campeche"
                       5         =  "Coahuila"
                       6         =  "Colima"
                       7         =  "Chiapas"
                       8         =  "Chihuahua"
                       9         =  "Distrito Federal"
                       10        =  "Durango"
                       11        =  "Guanajuato"
                       12        =  "Guerrero"
                       13        =  "Hidalgo"
                       14        =  "Jalisco"
                       15        =  "Mxico"
                       16        =  "Michoacn"
                       17        =  "Morelos"
                       18        =  "Nayarit"
                       19        =  "Nuevo Len"
                       20        =  "Oaxaca"
                       21        =  "Puebla"
                       22        =  "Quertaro"
                       23        =  "Quintana Roo"
                       24        =  "San Luis Potos"
                       25        =  "Sinaloa"
                       26        =  "Sonora"
                       27        =  "Tabasco"
                       28        =  "Tamaulipas"
                       29        =  "Tlaxcala"
                       30        =  "Veracruz"
                       31        =  "Yucatn"
                       32        =  "Zacatecas";
     VALUE id_modF     1         =  "Urbana Pblica"
                       2         =  "Rural Pblica"
                       3         =  "Educacin Indgena"
                       4         =  "Curso Comunitario"
                       5         =  "Privada"
                       6         =  "General"
                       7         =  "Tcnica"
                       8         =  "Telesecundaria"
                       9         =  "Privada";
     VALUE $modF       "UP"      =  "Urbano Pblico"
                       "RP"      =  "Rural Pblico"
                       "EI"      =  "Educacin Indgena"
                       "CC"      =  "Cursos Comunitarios"
                       "UPV"     =  "Privada"
                       "GRAL"    =  "General"
                       "TEC"     =  "Tcnica"
                       "TV"      =  "Telesecundaria"
                       "PRIV"    =  "Privada";
     VALUE $entestF    "999"     =  "Respuesta omitida";
     VALUE sexoF       1         =  "Hombre"
                       2         =  "Mujer"
                       8         =  "Respuesta mltiple"
                       9         =  "Respuesta omitida";
     VALUE edad_acF    7         =  "7 aos"
                       8         =  "8 aos"
                       9         =  "9 aos"
                       10        =  "10 aos"
                       11        =  "11 aos"
                       12        =  "12 aos"
                       98        =  "Respuesta mltiple"
                       99        =  "Respuesta omitida";
     VALUE mes_nacF    1         =  "Enero"
                       2         =  "Febrero"
                       3         =  "Marzo"
                       4         =  "Abril"
                       5         =  "Mayo"
                       6         =  "Junio"
                       7         =  "Julio"
                       8         =  "Agosto"
                       9         =  "Septiembre"
                       10        =  "Octubre"
                       11        =  "Noviembre"
                       12        =  "Diciembre"
                       98        =  "Respuesta mltiple"
                       99        =  "Respuesta omitida";
     VALUE edadF       99        =  "Respuesta omitida";
     VALUE edadCF      1         =  "8 aos o menos"
                       2         =  "9 aos"
                       3         =  "10 aos"
                       4         =  "11 aos o ms"
                       9         =  "Respuesta omitida";
     VALUE edadNF      1         =  "Edad normativa"
                       2         =  "Extra-edad"
                       9         =  "Respuesta omitida";
     VALUE edadAF      0         =  "Sin edad anticipada"
                       1         =  "Edad anticipada"
                       9         =  "Respuesta omitida";
     VALUE edadEF      0         =  "Sin extra edad severa"
                       1         =  "Extra edad severa"
                       9         =  "Respuesta omitida";
     VALUE docenF      99999     =  "Respuesta omitida";
     VALUE reactF      0         =  "Fallo"
                       1         =  "Acierto"
                       5         =  "Reactivo no alcanzado (se considera como no administrado)"
                       6         =  "Reactivo no administrado por error de impresin"
                       7         =  "Reactivo no administrado (No se incluy en su cuadernillo de examen)";
     VALUE nvlF        1         =  "Por debajo del nivel bsico"
                       2         =  "Bsico"
                       3         =  "Medio"
                       4         =  "Avanzado";
     VALUE nvblF       0         =  "Por debajo del nivel bsico"
                       1         =  "Al menos el nivel bsico";
     VALUE nvmlF       0         =  "Por debajo del nivel medio"
                       1         =  "Al menos el nivel medio";
RUN;



DATA INEE.Excale03_2014_Alum_CN;
   LENGTH
       NACIONAL    3
       ESCUELA     4
       ID_ENT      3
       NOM_ENT     $19
       ID_MOD      3
       MOD         $4
       ESTRATO     $7
       ENTEST      $6
       ALUMNO      5
       ID_INSTR    $15
       SEXO        3
       EDAD_AC     3
       MES_NAC     3
       EDAD        8
       EDAD_ACC    3
       EDAD_N      3
       EDAD_ANT    3
       EDAD_EES    3
       W_ALU       8
       DOCENTE     5
       PNA_01      3
       PNA_02      3
       PNA_03      3
       PNA_04      3
       PNA_05      3
       PNA_07      3
       PNA_08      3
       PNA_09      3
       PNA_10      3
       PNA_11      3
       PNA_12      3
       PNA_13      3
       PNA_14      3
       PNA_15      3
       PNA_16      3
       PNB_01      3
       PNB_02      3
       PNB_03      3
       PNB_04      3
       PNB_05      3
       PNB_06      3
       PNB_07      3
       PNB_08      3
       PNB_09      3
       PNB_10      3
       PNB_11      3
       PNB_12      3
       PNB_13      3
       PNB_14      3
       PNB_15      3
       PNB_16      3
       PNB_17      3
       PNC_01      3
       PNC_02      3
       PNC_03      3
       PNC_04      3
       PNC_05      3
       PNC_06      3
       PNC_08      3
       PNC_09      3
       PNC_10      3
       PNC_11      3
       PNC_12      3
       PNC_13      3
       PNC_14      3
       PNC_15      3
       PNC_16      3
       PNC_17      3
       PV1CN       8
       PV2CN       8
       PV3CN       8
       PV4CN       8
       PV5CN       8
       CNNVL1      3
       CNNVL2      3
       CNNVL3      3
       CNNVL4      3
       CNNVL5      3
       CNNVBL1     3
       CNNVBL2     3
       CNNVBL3     3
       CNNVBL4     3
       CNNVBL5     3
       CNNVML1     3
       CNNVML2     3
       CNNVML3     3
       CNNVML4     3
       CNNVML5     3
       WVARSTRR    3
       W_FSTR1     8
       W_FSTR2     8
       W_FSTR3     8
       W_FSTR4     8
       W_FSTR5     8
       W_FSTR6     8
       W_FSTR7     8
       W_FSTR8     8
       W_FSTR9     8
       W_FSTR10    8
       W_FSTR11    8
       W_FSTR12    8
       W_FSTR13    8
       W_FSTR14    8
       W_FSTR15    8
       W_FSTR16    8
       W_FSTR17    8
       W_FSTR18    8
       W_FSTR19    8
       W_FSTR20    8
       W_FSTR21    8
       W_FSTR22    8
       W_FSTR23    8
       W_FSTR24    8
       W_FSTR25    8
       W_FSTR26    8
       W_FSTR27    8
       W_FSTR28    8
       W_FSTR29    8
       W_FSTR30    8
       W_FSTR31    8
       W_FSTR32    8
       W_FSTR33    8
       W_FSTR34    8
       W_FSTR35    8
       W_FSTR36    8
       W_FSTR37    8
       W_FSTR38    8
       W_FSTR39    8
       W_FSTR40    8
       W_FSTR41    8
       W_FSTR42    8
       W_FSTR43    8
       W_FSTR44    8
       W_FSTR45    8
       W_FSTR46    8
       W_FSTR47    8
       W_FSTR48    8
       W_FSTR49    8
       W_FSTR50    8
       W_FSTR51    8
       W_FSTR52    8
       W_FSTR53    8
       W_FSTR54    8
       W_FSTR55    8
       W_FSTR56    8
       W_FSTR57    8
       W_FSTR58    8
       W_FSTR59    8
       W_FSTR60    8
       W_FSTR61    8
       W_FSTR62    8
       W_FSTR63    8
       W_FSTR64    8
       W_FSTR65    8
       W_FSTR66    8
       W_FSTR67    8
       W_FSTR68    8
       W_FSTR69    8
       W_FSTR70    8
       W_FSTR71    8
       W_FSTR72    8
       W_FSTR73    8
       W_FSTR74    8
       W_FSTR75    8
       W_FSTR76    8
       W_FSTR77    8
       W_FSTR78    8
       W_FSTR79    8
       W_FSTR80    8
       W_FSTR81    8
       W_FSTR82    8
       W_FSTR83    8
       W_FSTR84    8
       W_FSTR85    8
       W_FSTR86    8
       W_FSTR87    8
       W_FSTR88    8
       W_FSTR89    8
       W_FSTR90    8
       W_FSTR91    8
       W_FSTR92    8
       W_FSTR93    8
       W_FSTR94    8
       W_FSTR95    8
       W_FSTR96    8
       W_FSTR97    8
       W_FSTR98    8
       W_FSTR99    8
       W_FSTR100   8
 ;

INFILE alum MISSOVER LINESIZE = 1307;
   INPUT
     NACIONAL          1 - 1
     ESCUELA           2 - 5
     ID_ENT            6 - 7
     NOM_ENT           8 - 26
     ID_MOD           27 - 27
     MOD              28 - 31
     ESTRATO          32 - 39
     ENTEST           40 - 45
     ALUMNO           46 - 50
     ID_INSTR         51 - 65
     SEXO             66 - 66
     EDAD_AC          67 - 68
     MES_NAC          69 - 70
     EDAD             71 - 81
     EDAD_ACC         82 - 82
     EDAD_N           83 - 83
     EDAD_ANT         84 - 84
     EDAD_EES         85 - 85
     W_ALU            86 - 96
     DOCENTE          97 - 101
     PNA_01          102 - 102
     PNA_02          103 - 103
     PNA_03          104 - 104
     PNA_04          105 - 105
     PNA_05          106 - 106
     PNA_07          107 - 107
     PNA_08          108 - 108
     PNA_09          109 - 109
     PNA_10          110 - 110
     PNA_11          111 - 111
     PNA_12          112 - 112
     PNA_13          113 - 113
     PNA_14          114 - 114
     PNA_15          115 - 115
     PNA_16          116 - 116
     PNB_01          117 - 117
     PNB_02          118 - 118
     PNB_03          119 - 119
     PNB_04          120 - 120
     PNB_05          121 - 121
     PNB_06          122 - 122
     PNB_07          123 - 123
     PNB_08          124 - 124
     PNB_09          125 - 125
     PNB_10          126 - 126
     PNB_11          127 - 127
     PNB_12          128 - 128
     PNB_13          129 - 129
     PNB_14          130 - 130
     PNB_15          131 - 131
     PNB_16          132 - 132
     PNB_17          133 - 133
     PNC_01          134 - 134
     PNC_02          135 - 135
     PNC_03          136 - 136
     PNC_04          137 - 137
     PNC_05          138 - 138
     PNC_06          139 - 139
     PNC_08          140 - 140
     PNC_09          141 - 141
     PNC_10          142 - 142
     PNC_11          143 - 143
     PNC_12          144 - 144
     PNC_13          145 - 145
     PNC_14          146 - 146
     PNC_15          147 - 147
     PNC_16          148 - 148
     PNC_17          149 - 149
     PV1CN           150 - 157
     PV2CN           158 - 165
     PV3CN           166 - 173
     PV4CN           174 - 181
     PV5CN           182 - 189
     CNNVL1          190 - 190
     CNNVL2          191 - 191
     CNNVL3          192 - 192
     CNNVL4          193 - 193
     CNNVL5          194 - 194
     CNNVBL1         195 - 195
     CNNVBL2         196 - 196
     CNNVBL3         197 - 197
     CNNVBL4         198 - 198
     CNNVBL5         199 - 199
     CNNVML1         200 - 200
     CNNVML2         201 - 201
     CNNVML3         202 - 202
     CNNVML4         203 - 203
     CNNVML5         204 - 204
     WVARSTRR        205 - 207
     W_FSTR1         208 - 218
     W_FSTR2         219 - 229
     W_FSTR3         230 - 240
     W_FSTR4         241 - 251
     W_FSTR5         252 - 262
     W_FSTR6         263 - 273
     W_FSTR7         274 - 284
     W_FSTR8         285 - 295
     W_FSTR9         296 - 306
     W_FSTR10        307 - 317
     W_FSTR11        318 - 328
     W_FSTR12        329 - 339
     W_FSTR13        340 - 350
     W_FSTR14        351 - 361
     W_FSTR15        362 - 372
     W_FSTR16        373 - 383
     W_FSTR17        384 - 394
     W_FSTR18        395 - 405
     W_FSTR19        406 - 416
     W_FSTR20        417 - 427
     W_FSTR21        428 - 438
     W_FSTR22        439 - 449
     W_FSTR23        450 - 460
     W_FSTR24        461 - 471
     W_FSTR25        472 - 482
     W_FSTR26        483 - 493
     W_FSTR27        494 - 504
     W_FSTR28        505 - 515
     W_FSTR29        516 - 526
     W_FSTR30        527 - 537
     W_FSTR31        538 - 548
     W_FSTR32        549 - 559
     W_FSTR33        560 - 570
     W_FSTR34        571 - 581
     W_FSTR35        582 - 592
     W_FSTR36        593 - 603
     W_FSTR37        604 - 614
     W_FSTR38        615 - 625
     W_FSTR39        626 - 636
     W_FSTR40        637 - 647
     W_FSTR41        648 - 658
     W_FSTR42        659 - 669
     W_FSTR43        670 - 680
     W_FSTR44        681 - 691
     W_FSTR45        692 - 702
     W_FSTR46        703 - 713
     W_FSTR47        714 - 724
     W_FSTR48        725 - 735
     W_FSTR49        736 - 746
     W_FSTR50        747 - 757
     W_FSTR51        758 - 768
     W_FSTR52        769 - 779
     W_FSTR53        780 - 790
     W_FSTR54        791 - 801
     W_FSTR55        802 - 812
     W_FSTR56        813 - 823
     W_FSTR57        824 - 834
     W_FSTR58        835 - 845
     W_FSTR59        846 - 856
     W_FSTR60        857 - 867
     W_FSTR61        868 - 878
     W_FSTR62        879 - 889
     W_FSTR63        890 - 900
     W_FSTR64        901 - 911
     W_FSTR65        912 - 922
     W_FSTR66        923 - 933
     W_FSTR67        934 - 944
     W_FSTR68        945 - 955
     W_FSTR69        956 - 966
     W_FSTR70        967 - 977
     W_FSTR71        978 - 988
     W_FSTR72        989 - 999
     W_FSTR73       1000 - 1010
     W_FSTR74       1011 - 1021
     W_FSTR75       1022 - 1032
     W_FSTR76       1033 - 1043
     W_FSTR77       1044 - 1054
     W_FSTR78       1055 - 1065
     W_FSTR79       1066 - 1076
     W_FSTR80       1077 - 1087
     W_FSTR81       1088 - 1098
     W_FSTR82       1099 - 1109
     W_FSTR83       1110 - 1120
     W_FSTR84       1121 - 1131
     W_FSTR85       1132 - 1142
     W_FSTR86       1143 - 1153
     W_FSTR87       1154 - 1164
     W_FSTR88       1165 - 1175
     W_FSTR89       1176 - 1186
     W_FSTR90       1187 - 1197
     W_FSTR91       1198 - 1208
     W_FSTR92       1209 - 1219
     W_FSTR93       1220 - 1230
     W_FSTR94       1231 - 1241
     W_FSTR95       1242 - 1252
     W_FSTR96       1253 - 1263
     W_FSTR97       1264 - 1274
     W_FSTR98       1275 - 1285
     W_FSTR99       1286 - 1296
     W_FSTR100      1297 - 1307
 ;


 LABEL
     NACIONAL    =  "Variable auxiliar para obtener promedios nacionales"
     ESCUELA     =  "Identificador de la escuela"
     ID_ENT      =  "Entidad federativa (identificador numrico)"
     NOM_ENT     =  "Entidad federativa"
     ID_MOD      =  "Estrato escolar o Modalidad educativa (identificador numrico)"
     MOD         =  "Estrato escolar o Modalidad educativa"
     ESTRATO     =  "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
     ENTEST      =  "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
     ALUMNO      =  "Identificador del alumno"
     ID_INSTR    =  "Identificador del cuadernillo de examen"
     SEXO        =  "Sexo del alumno"
     EDAD_AC     =  "Edad en aos cumplidos (al momento de la aplicacin)"
     MES_NAC     =  "Mes de nacimiento del alumno"
     EDAD        =  "Edad del alumno al mes de mayo de 2014, en aos (al momento de la aplicacin). Incluye los meses cumplidos (decimales)"
     EDAD_ACC    =  "Edad en aos cumplidos codificada (con recodificacin y colapsamiento de categoras de la variable EDAD_AC)"
     EDAD_N      =  "Edad normativa. Supone el ingreso al primero de primaria con 6 aos cumplidos (o menos) al primero de septiembre"
     EDAD_ANT    =  "Edad anticipada. Variable indicadora de los alumnos que ingresaron al primero de primaria con menos de 6 aos cumplidos al primero de septiembre"
     EDAD_EES    =  "Extra edad severa. Variable indicadora de los alumnos que tienen dos aos o ms de retraso en el sistema escolar"
     W_ALU       =  "Peso muestral o ponderador del alumno"
     DOCENTE     =  "Identificador del docente que imparte clases al alumno"
     PNA_01      =  "Identificar una medida para prevenir accidentes que pueden lesionar el sistema locomotor."
     PNA_02      =  "Identificar el aprovechamiento del sonido en aparatos para atender una necesidad."
     PNA_03      =  "Relacionar el consumo de alimentos de los tres grupos con el buen funcionamiento del cuerpo."
     PNA_04      =  "Reconocer un animal que posee estructuras respiratorias semejantes a las del ser humano."
     PNA_05      =  "Identificar una situacin de abuso sexual."
     PNA_07      =  "Reconocer el aprovechamiento de los imanes en una situacin cotidiana."
     PNA_08      =  "Identificar, mediante comparaciones, lo que ocurre al modificar la proporcin de los componentes de una mezcla."
     PNA_09      =  "Identificar una recomendacin para prevenir el abuso sexual."
     PNA_10      =  "Identificar una accin que contamina el ambiente debido al manejo inadecuado de residuos."
     PNA_11      =  "Identificar las fases lunares."
     PNA_12      =  "Reconocer el proceso general de nutricin."
     PNA_13      =  "Reconocer la relacin entre las estructuras respiratorias de un animal y el ambiente en el que vive."
     PNA_14      =  "Identificar cambios de estado fsico de un material por variacin en la temperatura."
     PNA_15      =  "Identificar que las plantas elaboran sus propios alimentos."
     PNA_16      =  "Identificar un objeto que puede ser atrado por un imn."
     PNB_01      =  "Reconocer efectos en el ambiente derivados del aprovechamiento de recursos para satisfacer necesidades humanas."
     PNB_02      =  "Reconocer la importancia de beber agua simple potable para hidratar el cuerpo."
     PNB_03      =  "Identificar la participacin del sistema circulatorio en la nutricin."
     PNB_04      =  "Identificar distintos materiales que se presentan en el mismo estado fsico."
     PNB_05      =  "Reconocer la importancia de manifestar temores ante el riesgo de violencia escolar."
     PNB_06      =  "Relacionar un material del entorno con su estado fsico."
     PNB_07      =  "Reconocer semejanzas en la forma en que los seres humanos y otros animales se alimentan."
     PNB_08      =  "Identificar alimentos de los tres grupos representados en el Plato del Bien Comer."
     PNB_09      =  "Reconocer el aprovechamiento de un recurso natural para satisfacer una necesidad bsica."
     PNB_10      =  "Identificar una accin para cuidar el aire en la naturaleza."
     PNB_11      =  "Identificar una accin que favorece el consumo sustentable."
     PNB_12      =  "Identificar el tipo de alimentacin de algn animal en su medio natural."
     PNB_13      =  "Identificar las caractersticas de algunos materiales al cambiar de un estado fsico a otro."
     PNB_14      =  "Identificar una situacin de violencia escolar."
     PNB_15      =  "Identificar el componente que est en mayor proporcin en una mezcla."
     PNB_16      =  "Identificar un utensilio que reduce el esfuerzo en alguna actividad."
     PNB_17      =  "Identificar el tono, el timbre y la intensidad como caractersticas del sonido."
     PNC_01      =  "Identificar la causa de un accidente en el que se lesion el sistema locomotor."
     PNC_02      =  "Reconocer actividades cotidianas en las que  se aprovecha la solubilidad de algunos materiales en el agua."
     PNC_03      =  "Reconocer la participacin de los sistemas nervioso y muscular en el movimiento del cuerpo."
     PNC_04      =  "Identificar el riesgo que presenta la cercana entre los rganos sexuales externos y los orificios de salida de orina y heces."
     PNC_05      =  "Identificar una mezcla de materiales comunes."
     PNC_06      =  "Identificar una accin para prevenir la violencia en la escuela."
     PNC_08      =  "Identificar residuos orgnicos."
     PNC_09      =  "Identificar una accin para cuidar el agua en la naturaleza."
     PNC_10      =  "Reconocer una accin de cuidado del suelo para el crecimiento y desarrollo de las plantas."
     PNC_11      =  "Reconocer el beneficio ambiental derivado de una accin de consumo sustentable."
     PNC_12      =  "Identificar materiales solubles en agua."
     PNC_13      =  "Identificar como ocurre el da y la noche."
     PNC_14      =  "Reconocer una accin que ayuda a fortalecer el sistema locomotor."
     PNC_15      =  "Identificar una medida de higiene de los rganos sexuales externos para evitar infecciones."
     PNC_16      =  "Identificar la importancia del termmetro en una situacin cotidiana."
     PNC_17      =  "Reconocer una situacin en la que un objeto se mueve por la aplicacin de una fuerza."
     PV1CN       =  "Primer valor plausible de Ciencias"
     PV2CN       =  "Segundo valor plausible de Ciencias"
     PV3CN       =  "Tercer valor plausible de Ciencias"
     PV4CN       =  "Cuarto valor plausible de Ciencias"
     PV5CN       =  "Quinto valor plausible de Ciencias"
     CNNVL1      =  "Nivel de logro en Ciencias. Asociado a PV1CN. (Cuatro niveles)"
     CNNVL2      =  "Nivel de logro en Ciencias. Asociado a PV2CN. (Cuatro niveles)"
     CNNVL3      =  "Nivel de logro en Ciencias. Asociado a PV3CN. (Cuatro niveles)"
     CNNVL4      =  "Nivel de logro en Ciencias. Asociado a PV4CN. (Cuatro niveles)"
     CNNVL5      =  "Nivel de logro en Ciencias. Asociado a PV5CN. (Cuatro niveles)"
     CNNVBL1     =  "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias. Asociado a PV1CN."
     CNNVBL2     =  "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias. Asociado a PV2CN."
     CNNVBL3     =  "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias. Asociado a PV3CN."
     CNNVBL4     =  "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias. Asociado a PV4CN."
     CNNVBL5     =  "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias. Asociado a PV5CN."
     CNNVML1     =  "Identifica si el alumno pertenece al menos al nivel medio de logro en Ciencias. Asociado a PV1CN."
     CNNVML2     =  "Identifica si el alumno pertenece al menos al nivel medio de logro en Ciencias. Asociado a PV2CN."
     CNNVML3     =  "Identifica si el alumno pertenece al menos al nivel medio de logro en Ciencias. Asociado a PV3CN."
     CNNVML4     =  "Identifica si el alumno pertenece al menos al nivel medio de logro en Ciencias. Asociado a PV4CN."
     CNNVML5     =  "Identifica si el alumno pertenece al menos al nivel medio de logro en Ciencias. Asociado a PV5CN."
     WVARSTRR    =  "Identificador del pseudoestrato (1 a 100) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
     W_FSTR1     =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR2     =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR3     =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR4     =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR5     =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR6     =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR7     =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR8     =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR9     =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR10    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR11    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR12    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR13    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR14    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR15    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR16    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR17    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR18    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR19    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR20    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR21    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR22    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR23    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR24    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR25    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR26    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR27    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR28    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR29    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR30    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR31    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR32    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR33    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR34    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR35    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR36    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR37    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR38    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR39    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR40    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR41    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR42    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR43    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR44    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR45    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR46    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR47    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR48    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR49    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR50    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR51    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR52    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR53    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR54    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR55    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR56    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR57    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR58    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR59    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR60    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR61    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR62    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR63    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR64    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR65    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR66    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR67    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR68    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR69    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR70    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR71    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR72    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR73    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR74    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR75    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR76    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR77    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR78    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR79    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR80    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR81    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR82    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR83    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR84    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR85    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR86    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR87    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR88    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR89    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR90    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR91    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR92    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR93    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR94    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR95    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR96    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR97    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR98    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR99    =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
     W_FSTR100   =  "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
 ;



 FORMAT
       NACIONAL      1.
       ESCUELA       4.
       ID_ENT        id_entF.
       NOM_ENT       $char19.
       ID_MOD        id_modF.
       MOD           $modF.
       ESTRATO       $char7.
       ENTEST        $entestF.
       ALUMNO        5.
       ID_INSTR      $char15.
       SEXO          sexoF.
       EDAD_AC       edad_acF.
       MES_NAC       mes_nacF.
       EDAD          edadF.
       EDAD_ACC      edadCF.
       EDAD_N        edadNF.
       EDAD_ANT      edadAF.
       EDAD_EES      edadEF.
       DOCENTE       docenF.
       PNA_01        reactF.
       PNA_02        reactF.
       PNA_03        reactF.
       PNA_04        reactF.
       PNA_05        reactF.
       PNA_07        reactF.
       PNA_08        reactF.
       PNA_09        reactF.
       PNA_10        reactF.
       PNA_11        reactF.
       PNA_12        reactF.
       PNA_13        reactF.
       PNA_14        reactF.
       PNA_15        reactF.
       PNA_16        reactF.
       PNB_01        reactF.
       PNB_02        reactF.
       PNB_03        reactF.
       PNB_04        reactF.
       PNB_05        reactF.
       PNB_06        reactF.
       PNB_07        reactF.
       PNB_08        reactF.
       PNB_09        reactF.
       PNB_10        reactF.
       PNB_11        reactF.
       PNB_12        reactF.
       PNB_13        reactF.
       PNB_14        reactF.
       PNB_15        reactF.
       PNB_16        reactF.
       PNB_17        reactF.
       PNC_01        reactF.
       PNC_02        reactF.
       PNC_03        reactF.
       PNC_04        reactF.
       PNC_05        reactF.
       PNC_06        reactF.
       PNC_08        reactF.
       PNC_09        reactF.
       PNC_10        reactF.
       PNC_11        reactF.
       PNC_12        reactF.
       PNC_13        reactF.
       PNC_14        reactF.
       PNC_15        reactF.
       PNC_16        reactF.
       CNNVL1        nvlF.
       CNNVL2        nvlF.
       CNNVL3        nvlF.
       CNNVL4        nvlF.
       CNNVL5        nvlF.
       CNNVBL1       nvblF.
       CNNVBL2       nvblF.
       CNNVBL3       nvblF.
       CNNVBL4       nvblF.
       CNNVBL5       nvblF.
       CNNVML1       nvmlF.
       CNNVML2       nvmlF.
       CNNVML3       nvmlF.
       CNNVML4       nvmlF.
       CNNVML5       nvmlF.
       wvarstrr      3.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
 IF  sexo = 8 THEN  sexo = .M;
 IF  edad_ac = 98 THEN  edad_ac = .M;
 IF  mes_nac = 98 THEN  mes_nac = .M;
 IF  entest = "999" THEN  entest = .S;
 IF  Docente = 99999 THEN  Docente = .S;


 ARRAY perdidos1(5)  sexo edad_acc edad_n edad_ant edad_ant;
 DO  i=1 TO 5;
       IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
 END;

 ARRAY perdidos2(3)  edad edad_ac mes_nac;
 DO  i=1 TO 3;
       IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
 END;


 ARRAY perdidos3(48)
               pna_01 pna_02 pna_03 pna_04 pna_05 pna_07 pna_08 pna_09 pna_10
               pna_11 pna_12 pna_13 pna_14 pna_15 pna_16 pnb_01 pnb_02 pnb_03
               pnb_04 pnb_05 pnb_06 pnb_07 pnb_08 pnb_09 pnb_10 pnb_11 pnb_12
               pnb_13 pnb_14 pnb_15 pnb_16 pnb_17 pnc_01 pnc_02 pnc_03 pnc_04
               pnc_05 pnc_06 pnc_08 pnc_09 pnc_10 pnc_11 pnc_12 pnc_13 pnc_14
               pnc_15 pnc_16 pnc_17;
 DO  i=1 TO 48;
        IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
        IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
 END;

 drop i;
RUN;

